Explanations
============

These pages are meant to act as more in-depth discussions of how penguins works behind the scenes.
So far, there is only one page, but if you have any ideas for what may be useful here, feel free to `get in touch <https://github.com/yongrenjie/penguins/issues>`_.

.. toctree::
   :maxdepth: 2

   paradigm
